#[non_exhaustive]pub struct OperatingPointSeries {
pub time_axis: TimeAxis,
pub points: Vec<OperatingPoint>,
pub metadata: BTreeMap<String, Value>,
}Expand description
A format neutral series of operating points over a package’s static payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time_axis: TimeAxisShared period count, durations, and labels.
points: Vec<OperatingPoint>Ordered operating states. Each state is addressed by its index.
metadata: BTreeMap<String, Value>Metadata from the source format, such as source_format.
Implementations
Sourceimpl OperatingPointSeries
impl OperatingPointSeries
pub fn new(time_axis: TimeAxis, points: Vec<OperatingPoint>) -> Self
pub fn is_empty(&self) -> bool
Sourcepub fn point(&self, index: usize) -> Option<&OperatingPoint>
pub fn point(&self, index: usize) -> Option<&OperatingPoint>
Return the first point with index.
Use OperatingPointSeries::unique_point when duplicate indices must be
rejected instead of collapsed.
Sourcepub fn unique_point(&self, index: usize) -> Result<Option<&OperatingPoint>>
pub fn unique_point(&self, index: usize) -> Result<Option<&OperatingPoint>>
Return the only point with index, rejecting duplicate period indices.
pub fn with_metadata(self, metadata: BTreeMap<String, Value>) -> Self